@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from django.conf import settings
+from django.conf import settings  # noqa
 
 from appconf import AppConf
 
